const fs = require(`fs-extra`);
const path = require(`path`);
const express = require(`express`);
// Middlewares
const checkHeaders = require(`../middlewares/checkHeaders`);
const isAuthenticated = require(`../middlewares/isAuthenticated`);
// Classes
const Articles = require(`../models/Articles`);

const conf = require(`../../../adminapi/objects/tribes/itm/adminapi.json`);
const currentmod = "Articles";
const log = conf.api.activelog.includes(currentmod);

const router = express.Router();

/**
 * @api {GET} /adminapi/articles/evaluation/:tribe/:articleid/:evaluation -set article evaluation
 * @apiName articleevaluation
 * @apiGroup Articles
 * @apiDescription Get evaluation about an articleid
 *
 * @apiParam {string} tribe an existing tribe where articles exist
 * @apiParam {string} articleid an existing articleid in tribe/objects/articles/itm
 * @apiParam {string} evaluation a value from 0 to 4 or follow
 *
 * @apiSuccess {object}  successfull
 * @apiSuccessExample {json} successfullmessage
 * HTTP/1.1 200 OK
 * {"status":200, "ref":"Articles", "msg":"evaluationsaved", "data":{article}}
 *
 * @apiError {object}  notfound
 * @apiErrorexampleExample {json} notfound
 * HTTP/1.1 200 OK
 * {"status":404, "ref":"Articles", "msg":"notfound", "data":{articleid}}
 *
 */
router.get(
  "/evaluation/:tribe/:articleid/:evaluation",
  checkHeaders,
  async (req, res) => {
    // @todo
    // Check if tribe/objects/articles/articleid exist
    // if evaluation between 0 and 4 then update article propertie "articleevaluations" by adding alias:evaluation if alias !=anonymous, if anonymous then add uuid:evaluation
    // recalculate articlevalue with an average of all evaluation
    // if evaluatiopn == follow then add alias to article.followupdate
    res.status(200).json({
      status: 200,
      ref: "Articles",
      msg: "evaluationsaved",
      data: { article: req.params.articleid },
    });
  }
);

/**
 * @api {post} adminapi/articles/comments  - pagan Post
 * @apiName addcomments
 * @apiGroup Articles
 * @apiDescription
 *  Add a comments to an articles or to another comments
 * @apiBody {string} [articleid] concern by the comment
 * @apiBody {string} [tribe] where the articleid is store
 * @apiBody {string} [comment] the comment text
 * @apiBody {string} [commentanswer] the position in a comment list in case of answer to a previous comment
 * 
 * @apiError {json} articleNotfound the tribe/objects/articles/itm does not exist 
 * @apiErrorExample {json}
 * HTTP/1.1 404 Not Found
   {"status":404,"ref":"Articles","msg":"articleidnotfound","data":{}}
 *
 * @apiSuccess {object}  
 * @apiSuccessExample {json} Success-Response:
 * HTTP/1.1 200 OK
 * {"status":200, "ref":"Articles", "msg":"commentsaved", "data":{}}
 * 
 */
router.post("/comments", checkHeaders, isAuthenticated, async (req, res) => {
  console.log('articles comment todo')
  res.status(200).json({
    status: 200,
    ref: "Articles",
    msg: "commentsaved",
    data: {},
  });
});
module.exports = router;
